@@ -8,17 +8,6 @@ from nltk.stem.wordnet import WordNetLemmatizer
 nltk.download('punkt')
 nltk.download('averaged_perceptron_tagger')
 nltk.download('stopwords')
-import subprocess
-
-def install(name):
-    subprocess.call(['pip', 'install', name])
-
-install('stanza')
-
-import stanza
-stanza.download('en')
-nlp = stanza.Pipeline('en')
-
 
 class Aspect:
     def recognizer(txt):
